#include <EEPROM.h> // include library for permanent memory, can store ints from 0-255 on 1000 addresses

int totalhours; // variable to store total quarter hours ridden
unsigned long runtime; // variable to store current runtime
int hours; // variable to hold converted integer runtime

int warningone; // variable for warning light one
int warningtwo; // warning light two
int warningthree; // warning light three

unsigned long onereset = 0; // variable for storing runtime until warning one gets reset
unsigned long tworeset = 0; 
unsigned long threereset = 0; 

const int convert = 3600000; // constant for converting milliseconds to quarter hours, 90,000

int swone; // variable for storing switch one status
int swtwo; // switch two
int swthree; //switch three

const int greenonepin = 2; // green LED pins
const int greentwopin = 3;
const int greenthreepin = 4;

const int warningonepin = 11; // warning LED pins
const int warningtwopin = 12;
const int warningthreepin = 13;

const int swonepin = 6; // switch pins
const int swtwopin = 7;
const int swthreepin = 8;

void setup() {
//  Serial.begin(9600); // initialize serial output

  totalhours = EEPROM.read(0); // read address 0 from EEPROM, this is where totalhours will be permanently stored
  warningone = EEPROM.read(11); // read address 11 from EEPROM, this is where warningone will be permanently stored
  warningtwo = EEPROM.read(12); // read address 12 from EEPROM, this is where warningtwo will be permanently stored
  warningthree = EEPROM.read(13); // read address 13 from EEPROM, this is where warningthree will be permanently stored

  pinMode(greenonepin, OUTPUT); // green LED #1
  pinMode(greentwopin, OUTPUT); // green LED #2
  pinMode(greenthreepin, OUTPUT); // green LED #3
  
  pinMode(warningonepin, OUTPUT); // warning LED #1
  pinMode(warningtwopin, OUTPUT); // warning LED #2
  pinMode(warningthreepin, OUTPUT); // warning LED #3

  pinMode(swonepin, INPUT_PULLUP); // switch #1
  pinMode(swtwopin, INPUT_PULLUP); // switch #2
  pinMode(swthreepin, INPUT_PULLUP); // switch #3
}

void loop() {
  
  runtime = millis() / convert; // milliseconds divided by 90,000 will calculate number of 15-minute intervals

  warningone = EEPROM.read(11);
  warningtwo = EEPROM.read(12);
  warningthree = EEPROM.read(13);
  
  hours = runtime; // round to integer
  totalhours = totalhours + hours; // add to the remembered total
  
  warningone = warningone + hours - onereset;
  warningtwo = warningtwo + hours - tworeset;
  warningthree = warningthree + hours - threereset;

  onereset = 0; // reset this variable to 0 so it doesn't subtract every time, only when while loop below is triggered
  tworeset = 0;
  threereset = 0;
  
  EEPROM.update(0,totalhours); // update if new total is different, i.e. if 15 minutes has passed
  EEPROM.update(11,warningone); // update warnings if new total is different, i.e. if 15 minutes has passed
  EEPROM.update(12,warningtwo); 
  EEPROM.update(13,warningthree); 
  
  totalhours = EEPROM.read(0);
  warningone = EEPROM.read(11);
  warningtwo = EEPROM.read(12);
  warningthree = EEPROM.read(13);
  
  hours = totalhours / 4; // calculate # of hours based off of stored total quarter hours

//  Serial.print("Total Quarter Hours: ");
//  Serial.println(totalhours); 
////  Serial.print("Warning One: ");
////  Serial.println(warningone);
//  Serial.print("Warning Two: ");
//  Serial.println(warningtwo);
////  Serial.print("Warning Three: ");
////  Serial.println(warningthree); 
//  delay(1000);

  swone = digitalRead(swonepin); // read switches
  swtwo = digitalRead(swtwopin);
  swthree = digitalRead(swthreepin);

  if (warningone > 14){ // illuminate warning one after 15 hours 
    digitalWrite(warningonepin, HIGH);
  }
  if (warningtwo > 40){ // illuminate warning two after 40 hours
    digitalWrite(warningtwopin, HIGH);
  }
  if (warningthree > 50){ // illuminate warning three after 50 hours 
    digitalWrite(warningthreepin, HIGH);
  }

  while (swone == HIGH) { // while switch is in 'reset' position, flash LED, and reset hours variable for that maintenance schedule to 0.
    EEPROM.update(11, 0);
    onereset = millis() / convert; // record current runtime time to subtract from total runtime later
    
    digitalWrite(warningonepin, HIGH);
    delay(100);
    digitalWrite(warningonepin, LOW);
    delay(100);
    swone = digitalRead(swonepin);
  }
  
  while (swtwo == HIGH) { // while switch is in 'reset' position, flash LED, and reset hours variable for that maintenance schedule to 0.
    EEPROM.update(12, 0);
    tworeset = millis() / convert; // record current runtime time to subtract from total runtime later
    
    digitalWrite(warningtwopin, HIGH);
    delay(100);
    digitalWrite(warningtwopin, LOW);
    delay(100);
    swtwo = digitalRead(swtwopin);
  }
  
  while (swthree == HIGH) { // while switch is in 'reset' position, flash LED, and reset hours variable for that maintenance schedule to 0.
    EEPROM.update(13, 0);
    threereset = millis() / convert; // record current runtime time to subtract from total runtime later
    
    digitalWrite(warningthreepin, HIGH);
    delay(100);
    digitalWrite(warningthreepin, LOW);
    delay(100);
    swthree = digitalRead(swthreepin);
  }

  while (hours > 100) { // the wearable hours display will reset every 100 hours 
    hours = hours - 100;
  }

  if (hours < 33) { // if total hours are between 0-33
    digitalWrite(greenonepin, HIGH); // illuminate first green LED
    digitalWrite(greentwopin, LOW);
    digitalWrite(greenthreepin, LOW);
    
  }
  else if (hours > 33 && hours < 66) { // if total hours are between 33-66
    digitalWrite(greenonepin, HIGH); // illuminate first two green LEDs
    digitalWrite(greentwopin, HIGH);
    digitalWrite(greenthreepin, LOW);
  }
  else if (hours > 66 && hours <= 100) {
    digitalWrite(greenonepin, HIGH); // illuminate all three green LEDs
    digitalWrite(greentwopin, HIGH);
    digitalWrite(greenthreepin, HIGH);
  }
}
